@@ -3,6 +3,7 @@ use Mojo::Base -strict;
   namespace=>'Mojolicious::Plugin::RoutesAuthDBI',
   prefix => 'test-admin',
   trust =>'foo-trust',
+  role_admin => 'Admins',
   schema => 'тестовая схема 156',
   sequence => '"public"."seq 156"',
   tables=>{
@@ -12,6 +13,7 @@ use Mojo::Base -strict;
     refs=>'связи',
     roles=>'роли доступа',
     routes=>'маршруты',
+    guests=>'гости',
   },
   admin_user => 'admin3',
   admin_pass => 'секрет',
